#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7.1
visibility:           public
id:                   text-builder-0.6.7.1-IWo7txowClX97t21hFdHi9
key:                  text-builder-0.6.7.1-IWo7txowClX97t21hFdHi9
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             Efficient strict text builder
description:          Text formatting library and efficient builder library.
category:             Text, Builders
abi:                  7142d0a13587ad2ac3c101fcf98f8e63
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7.1-IWo7txowClX97t21hFdHi9
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.4.1-K1h7zJS4Yqu4Q8Q0mogGYV

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

